@@ -189,7 +189,8 @@ void catalog_request(JCR *jcr, BSOCK *bs)
                check_if_volume_valid_or_recyclable(jcr, &mr, &reason);
             }
          }
-         if (!reason && mr.Enabled != 1) {
+
+         if (!reason && mr.Enabled != VOL_ENABLED) {
             reason = _("is not Enabled");
          }
          if (reason == NULL) {
