@@ -336,7 +336,7 @@ void set_pool_dbr_defaults_in_media_dbr(MEDIA_DBR *mr, POOL_DBR *pr)
    mr->LabelType = pr->LabelType;
    mr->MinBlocksize = pr->MinBlocksize;
    mr->MaxBlocksize = pr->MaxBlocksize;
-   mr->Enabled = 1;
+   mr->Enabled = VOL_ENABLED;
 }
 
 
@@ -465,7 +465,7 @@ static int add_cmd(UAContext *ua, const char *cmd)
       bsnprintf(mr.VolumeName, sizeof(mr.VolumeName), name, i);
       mr.Slot = Slot++;
       mr.InChanger = InChanger;
-      mr.Enabled = 1;
+      mr.Enabled = VOL_ENABLED;
       set_storageid_in_mr(store, &mr);
       Dmsg1(200, "Create Volume %s\n", mr.VolumeName);
       if (!db_create_media_record(ua->jcr, ua->db, &mr)) {
@@ -1804,9 +1804,8 @@ static int time_cmd(UAContext *ua, const char *cmd)
 {
    char sdt[50];
    time_t ttime = time(NULL);
-   struct tm tm;
-   (void)localtime_r(&ttime, &tm);
-   strftime(sdt, sizeof(sdt), "%a %d-%b-%Y %H:%M:%S", &tm);
+
+   bstrftime(sdt, sizeof(sdt), ttime, "%a %d-%b-%Y %H:%M:%S");
    ua->send_msg("%s\n", sdt);
    return 1;
 }
