@@ -115,7 +115,7 @@ static char OKpluginoptions[] =
 extern bool finish_cmd(JCR *jcr);
 extern bool job_cmd(JCR *jcr);
 extern bool nextrun_cmd(JCR *jcr);
-extern bool qstatus_cmd(JCR *jcr);
+extern bool dotstatus_cmd(JCR *jcr);
 //extern bool query_cmd(JCR *jcr);
 extern bool status_cmd(JCR *sjcr);
 extern bool use_cmd(JCR *jcr);
@@ -190,7 +190,7 @@ static struct s_cmds cmds[] = {
    { "setdebug=", setdebug_cmd, false },    /* Set debug level */
    { "stats", stats_cmd, false },
    { "status", status_cmd, true },
-   { ".status", qstatus_cmd, true },
+   { ".status", dotstatus_cmd, true },
    { "unmount", unmount_cmd, false },
    { "use storage=", use_cmd, false },
    { NULL, NULL, false } /* list terminator */
